pub struct AcceptRefinementParams {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Debug for AcceptRefinementParams
impl Debug for AcceptRefinementParams
Sourceimpl<'de> Deserialize<'de> for AcceptRefinementParams
impl<'de> Deserialize<'de> for AcceptRefinementParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AcceptRefinementParams
impl JsonSchema for AcceptRefinementParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AcceptRefinementParams
impl RefUnwindSafe for AcceptRefinementParams
impl Send for AcceptRefinementParams
impl Sync for AcceptRefinementParams
impl Unpin for AcceptRefinementParams
impl UnsafeUnpin for AcceptRefinementParams
impl UnwindSafe for AcceptRefinementParams