pub struct CaptureParams {
pub content: String,
pub memory_type: Option<String>,
pub space: Option<String>,
pub entity: Option<String>,
pub confidence: Option<f32>,
pub supersedes: Option<String>,
pub structured_fields: Option<Map<String, Value>>,
pub retrieval_cue: Option<String>,
}Fields
content: Stringmemory_type: Option<String>space: Option<String>entity: Option<String>confidence: Option<f32>supersedes: Option<String>structured_fields: Option<Map<String, Value>>retrieval_cue: Option<String>Trait Implementations
Sourceimpl Debug for CaptureParams
impl Debug for CaptureParams
Sourceimpl<'de> Deserialize<'de> for CaptureParams
impl<'de> Deserialize<'de> for CaptureParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CaptureParams
impl JsonSchema for CaptureParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CaptureParams
impl RefUnwindSafe for CaptureParams
impl Send for CaptureParams
impl Sync for CaptureParams
impl Unpin for CaptureParams
impl UnsafeUnpin for CaptureParams
impl UnwindSafe for CaptureParams