pub struct ConfirmEntityParams {
pub entity_id: String,
pub confirmed: bool,
}Fields
entity_id: Stringconfirmed: boolTrait Implementations
Sourceimpl Debug for ConfirmEntityParams
impl Debug for ConfirmEntityParams
Sourceimpl<'de> Deserialize<'de> for ConfirmEntityParams
impl<'de> Deserialize<'de> for ConfirmEntityParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfirmEntityParams
impl JsonSchema for ConfirmEntityParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConfirmEntityParams
impl RefUnwindSafe for ConfirmEntityParams
impl Send for ConfirmEntityParams
impl Sync for ConfirmEntityParams
impl Unpin for ConfirmEntityParams
impl UnsafeUnpin for ConfirmEntityParams
impl UnwindSafe for ConfirmEntityParams