pub struct ConfirmMemoryParams {
pub memory_id: String,
}Fields
memory_id: StringTrait Implementations
Sourceimpl Debug for ConfirmMemoryParams
impl Debug for ConfirmMemoryParams
Sourceimpl<'de> Deserialize<'de> for ConfirmMemoryParams
impl<'de> Deserialize<'de> for ConfirmMemoryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfirmMemoryParams
impl JsonSchema for ConfirmMemoryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConfirmMemoryParams
impl RefUnwindSafe for ConfirmMemoryParams
impl Send for ConfirmMemoryParams
impl Sync for ConfirmMemoryParams
impl Unpin for ConfirmMemoryParams
impl UnsafeUnpin for ConfirmMemoryParams
impl UnwindSafe for ConfirmMemoryParams