pub struct CreateEntityParams {
pub name: String,
pub entity_type: String,
pub space: Option<String>,
pub confidence: Option<f32>,
}Fields
name: Stringentity_type: Stringspace: Option<String>confidence: Option<f32>Trait Implementations
Sourceimpl Debug for CreateEntityParams
impl Debug for CreateEntityParams
Sourceimpl<'de> Deserialize<'de> for CreateEntityParams
impl<'de> Deserialize<'de> for CreateEntityParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateEntityParams
impl JsonSchema for CreateEntityParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateEntityParams
impl RefUnwindSafe for CreateEntityParams
impl Send for CreateEntityParams
impl Sync for CreateEntityParams
impl Unpin for CreateEntityParams
impl UnsafeUnpin for CreateEntityParams
impl UnwindSafe for CreateEntityParams