pub struct CreateObservationParams {
pub entity_id: String,
pub content: String,
pub source_agent: Option<String>,
pub confidence: Option<f32>,
}Fields
entity_id: Stringcontent: Stringsource_agent: Option<String>confidence: Option<f32>Trait Implementations
Sourceimpl Debug for CreateObservationParams
impl Debug for CreateObservationParams
Sourceimpl<'de> Deserialize<'de> for CreateObservationParams
impl<'de> Deserialize<'de> for CreateObservationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateObservationParams
impl JsonSchema for CreateObservationParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateObservationParams
impl RefUnwindSafe for CreateObservationParams
impl Send for CreateObservationParams
impl Sync for CreateObservationParams
impl Unpin for CreateObservationParams
impl UnsafeUnpin for CreateObservationParams
impl UnwindSafe for CreateObservationParams