pub struct CreatePageParams {
pub title: String,
pub content: String,
pub summary: Option<String>,
pub entity_id: Option<String>,
pub domain: Option<String>,
pub source_memory_ids: Vec<String>,
}Fields
title: Stringcontent: Stringsummary: Option<String>entity_id: Option<String>domain: Option<String>source_memory_ids: Vec<String>Trait Implementations
Sourceimpl Debug for CreatePageParams
impl Debug for CreatePageParams
Sourceimpl<'de> Deserialize<'de> for CreatePageParams
impl<'de> Deserialize<'de> for CreatePageParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatePageParams
impl JsonSchema for CreatePageParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreatePageParams
impl RefUnwindSafe for CreatePageParams
impl Send for CreatePageParams
impl Sync for CreatePageParams
impl Unpin for CreatePageParams
impl UnsafeUnpin for CreatePageParams
impl UnwindSafe for CreatePageParams