pub struct CreateRelationParams {
pub from_entity: String,
pub to_entity: String,
pub relation_type: String,
}Fields
from_entity: Stringto_entity: Stringrelation_type: StringTrait Implementations
Sourceimpl Debug for CreateRelationParams
impl Debug for CreateRelationParams
Sourceimpl<'de> Deserialize<'de> for CreateRelationParams
impl<'de> Deserialize<'de> for CreateRelationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateRelationParams
impl JsonSchema for CreateRelationParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateRelationParams
impl RefUnwindSafe for CreateRelationParams
impl Send for CreateRelationParams
impl Sync for CreateRelationParams
impl Unpin for CreateRelationParams
impl UnsafeUnpin for CreateRelationParams
impl UnwindSafe for CreateRelationParams