pub struct DeleteObservationParams {
pub observation_id: String,
}Fields
observation_id: StringTrait Implementations
Sourceimpl Debug for DeleteObservationParams
impl Debug for DeleteObservationParams
Sourceimpl<'de> Deserialize<'de> for DeleteObservationParams
impl<'de> Deserialize<'de> for DeleteObservationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeleteObservationParams
impl JsonSchema for DeleteObservationParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteObservationParams
impl RefUnwindSafe for DeleteObservationParams
impl Send for DeleteObservationParams
impl Sync for DeleteObservationParams
impl Unpin for DeleteObservationParams
impl UnsafeUnpin for DeleteObservationParams
impl UnwindSafe for DeleteObservationParams