pub struct DistillParams {
pub page_id: Option<String>,
}Fields
page_id: Option<String>Trait Implementations
Sourceimpl Debug for DistillParams
impl Debug for DistillParams
Sourceimpl<'de> Deserialize<'de> for DistillParams
impl<'de> Deserialize<'de> for DistillParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DistillParams
impl JsonSchema for DistillParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DistillParams
impl RefUnwindSafe for DistillParams
impl Send for DistillParams
impl Sync for DistillParams
impl Unpin for DistillParams
impl UnsafeUnpin for DistillParams
impl UnwindSafe for DistillParams