pub struct GetMemoryRevisionsParams {
pub memory_id: String,
}Fields
memory_id: StringTrait Implementations
Sourceimpl Debug for GetMemoryRevisionsParams
impl Debug for GetMemoryRevisionsParams
Sourceimpl<'de> Deserialize<'de> for GetMemoryRevisionsParams
impl<'de> Deserialize<'de> for GetMemoryRevisionsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetMemoryRevisionsParams
impl JsonSchema for GetMemoryRevisionsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetMemoryRevisionsParams
impl RefUnwindSafe for GetMemoryRevisionsParams
impl Send for GetMemoryRevisionsParams
impl Sync for GetMemoryRevisionsParams
impl Unpin for GetMemoryRevisionsParams
impl UnsafeUnpin for GetMemoryRevisionsParams
impl UnwindSafe for GetMemoryRevisionsParams