pub struct GetPageParams {
pub page_id: String,
}Fields
page_id: StringTrait Implementations
Sourceimpl Debug for GetPageParams
impl Debug for GetPageParams
Sourceimpl<'de> Deserialize<'de> for GetPageParams
impl<'de> Deserialize<'de> for GetPageParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetPageParams
impl JsonSchema for GetPageParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetPageParams
impl RefUnwindSafe for GetPageParams
impl Send for GetPageParams
impl Sync for GetPageParams
impl Unpin for GetPageParams
impl UnsafeUnpin for GetPageParams
impl UnwindSafe for GetPageParams