pub struct GetPageSourcesParams {
pub page_id: String,
}Fields
page_id: StringTrait Implementations
Sourceimpl Debug for GetPageSourcesParams
impl Debug for GetPageSourcesParams
Sourceimpl<'de> Deserialize<'de> for GetPageSourcesParams
impl<'de> Deserialize<'de> for GetPageSourcesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetPageSourcesParams
impl JsonSchema for GetPageSourcesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetPageSourcesParams
impl RefUnwindSafe for GetPageSourcesParams
impl Send for GetPageSourcesParams
impl Sync for GetPageSourcesParams
impl Unpin for GetPageSourcesParams
impl UnsafeUnpin for GetPageSourcesParams
impl UnwindSafe for GetPageSourcesParams