pub struct ListMemoriesParams {
pub memory_type: Option<String>,
pub space: Option<String>,
pub limit: Option<usize>,
}Fields
memory_type: Option<String>space: Option<String>limit: Option<usize>Trait Implementations
Sourceimpl Debug for ListMemoriesParams
impl Debug for ListMemoriesParams
Sourceimpl<'de> Deserialize<'de> for ListMemoriesParams
impl<'de> Deserialize<'de> for ListMemoriesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListMemoriesParams
impl JsonSchema for ListMemoriesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListMemoriesParams
impl RefUnwindSafe for ListMemoriesParams
impl Send for ListMemoriesParams
impl Sync for ListMemoriesParams
impl Unpin for ListMemoriesParams
impl UnsafeUnpin for ListMemoriesParams
impl UnwindSafe for ListMemoriesParams