pub struct ListPagesRecentParams {
pub limit: Option<usize>,
pub since_ms: Option<i64>,
}Fields
limit: Option<usize>since_ms: Option<i64>Trait Implementations
Sourceimpl Debug for ListPagesRecentParams
impl Debug for ListPagesRecentParams
Sourceimpl<'de> Deserialize<'de> for ListPagesRecentParams
impl<'de> Deserialize<'de> for ListPagesRecentParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListPagesRecentParams
impl JsonSchema for ListPagesRecentParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListPagesRecentParams
impl RefUnwindSafe for ListPagesRecentParams
impl Send for ListPagesRecentParams
impl Sync for ListPagesRecentParams
impl Unpin for ListPagesRecentParams
impl UnsafeUnpin for ListPagesRecentParams
impl UnwindSafe for ListPagesRecentParams