pub struct ListPendingParams {
pub limit: Option<usize>,
}Fields
limit: Option<usize>Trait Implementations
Sourceimpl Debug for ListPendingParams
impl Debug for ListPendingParams
Sourceimpl<'de> Deserialize<'de> for ListPendingParams
impl<'de> Deserialize<'de> for ListPendingParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListPendingParams
impl JsonSchema for ListPendingParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListPendingParams
impl RefUnwindSafe for ListPendingParams
impl Send for ListPendingParams
impl Sync for ListPendingParams
impl Unpin for ListPendingParams
impl UnsafeUnpin for ListPendingParams
impl UnwindSafe for ListPendingParams