pub struct ListRefinementsParams {
pub action: Option<String>,
pub limit: Option<usize>,
}Fields
action: Option<String>limit: Option<usize>Trait Implementations
Sourceimpl Debug for ListRefinementsParams
impl Debug for ListRefinementsParams
Sourceimpl<'de> Deserialize<'de> for ListRefinementsParams
impl<'de> Deserialize<'de> for ListRefinementsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListRefinementsParams
impl JsonSchema for ListRefinementsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListRefinementsParams
impl RefUnwindSafe for ListRefinementsParams
impl Send for ListRefinementsParams
impl Sync for ListRefinementsParams
impl Unpin for ListRefinementsParams
impl UnsafeUnpin for ListRefinementsParams
impl UnwindSafe for ListRefinementsParams