pub struct ListSpacesParams {}Trait Implementations
Sourceimpl Debug for ListSpacesParams
impl Debug for ListSpacesParams
Sourceimpl<'de> Deserialize<'de> for ListSpacesParams
impl<'de> Deserialize<'de> for ListSpacesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListSpacesParams
impl JsonSchema for ListSpacesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListSpacesParams
impl RefUnwindSafe for ListSpacesParams
impl Send for ListSpacesParams
impl Sync for ListSpacesParams
impl Unpin for ListSpacesParams
impl UnsafeUnpin for ListSpacesParams
impl UnwindSafe for ListSpacesParams