pub struct RecallParams {
pub query: String,
pub limit: Option<usize>,
pub memory_type: Option<String>,
pub space: Option<String>,
}Fields
query: Stringlimit: Option<usize>memory_type: Option<String>space: Option<String>Trait Implementations
Sourceimpl Debug for RecallParams
impl Debug for RecallParams
Sourceimpl<'de> Deserialize<'de> for RecallParams
impl<'de> Deserialize<'de> for RecallParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecallParams
impl JsonSchema for RecallParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecallParams
impl RefUnwindSafe for RecallParams
impl Send for RecallParams
impl Sync for RecallParams
impl Unpin for RecallParams
impl UnsafeUnpin for RecallParams
impl UnwindSafe for RecallParams