pub struct SearchPagesParams {
pub query: String,
pub limit: Option<usize>,
pub page_type: Option<String>,
}Fields
query: Stringlimit: Option<usize>page_type: Option<String>Trait Implementations
Sourceimpl Debug for SearchPagesParams
impl Debug for SearchPagesParams
Sourceimpl<'de> Deserialize<'de> for SearchPagesParams
impl<'de> Deserialize<'de> for SearchPagesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchPagesParams
impl JsonSchema for SearchPagesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchPagesParams
impl RefUnwindSafe for SearchPagesParams
impl Send for SearchPagesParams
impl Sync for SearchPagesParams
impl Unpin for SearchPagesParams
impl UnsafeUnpin for SearchPagesParams
impl UnwindSafe for SearchPagesParams