pub struct UpdateObservationParams {
pub observation_id: String,
pub content: String,
}Fields
observation_id: Stringcontent: StringTrait Implementations
Sourceimpl Debug for UpdateObservationParams
impl Debug for UpdateObservationParams
Sourceimpl<'de> Deserialize<'de> for UpdateObservationParams
impl<'de> Deserialize<'de> for UpdateObservationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateObservationParams
impl JsonSchema for UpdateObservationParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateObservationParams
impl RefUnwindSafe for UpdateObservationParams
impl Send for UpdateObservationParams
impl Sync for UpdateObservationParams
impl Unpin for UpdateObservationParams
impl UnsafeUnpin for UpdateObservationParams
impl UnwindSafe for UpdateObservationParams