pub struct OrphanLink {
pub label: String,
pub count: i64,
}Expand description
One orphaned page link label aggregated across sources.
count is how many distinct source pages reference this label
without a matching target page existing.
Fields
label: Stringcount: i64Trait Implementations
Sourceimpl Clone for OrphanLink
impl Clone for OrphanLink
Sourcefn clone(&self) -> OrphanLink
fn clone(&self) -> OrphanLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OrphanLink
impl Debug for OrphanLink
Sourceimpl<'de> Deserialize<'de> for OrphanLink
impl<'de> Deserialize<'de> for OrphanLink
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OrphanLink, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OrphanLink, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OrphanLink
impl PartialEq for OrphanLink
Sourcefn eq(&self, other: &OrphanLink) -> bool
fn eq(&self, other: &OrphanLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OrphanLink
impl Serialize for OrphanLink
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for OrphanLink