pub struct RevisionAcceptResponse {
pub target_source_id: String,
pub revision_source_id: String,
pub wrote: bool,
}Expand description
Response returned by POST /api/memory/revision/{id}/accept.
Carries the now-consumed revision row id so agents can correlate with
their list_pending_revisions cache.
Fields
target_source_id: Stringrevision_source_id: Stringwrote: boolTrait Implementations
Sourceimpl Clone for RevisionAcceptResponse
impl Clone for RevisionAcceptResponse
Sourcefn clone(&self) -> RevisionAcceptResponse
fn clone(&self) -> RevisionAcceptResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RevisionAcceptResponse
impl Debug for RevisionAcceptResponse
Sourceimpl<'de> Deserialize<'de> for RevisionAcceptResponse
impl<'de> Deserialize<'de> for RevisionAcceptResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RevisionAcceptResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RevisionAcceptResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RevisionAcceptResponse
impl PartialEq for RevisionAcceptResponse
Sourcefn eq(&self, other: &RevisionAcceptResponse) -> bool
fn eq(&self, other: &RevisionAcceptResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RevisionAcceptResponse
impl Serialize for RevisionAcceptResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RevisionAcceptResponse